# DSPFTW

Starting points for learning digital signal processing.

## Lessons

Lessons can be found in the [doc directory](https://github.com/gershwinlabs/dspftw/tree/master/doc).

There is a Python package that corresponds with the lessons, also called `dspftw`.  You can install it with:

```sh
python3 -m pip install dspftw --user
```
